<h1 align="center">
  <br>
  <a href="https://github.com/dpr1005/Semisupervised-learning-and-instance
-selection-methods"><img src="./branding/is-ssl-2-flatten.png" 
alt="IS-SSL by DNX"></a>
  <br>
</h1>

---

# Semi-Supervised Algorithms

This project has the following algorithms:
- Co-Training
- Tri-Training
- Democratic Co-Learning
- Density Peaks
  - STDPNF

- Ensemble
  - RUSSEL

# Release Notes

See the commit logs at https://github.com/dpr1005/Semisupervised-learning-and-instance-selection-methods.